# tanjun.context

Standard implementations of Tanjun's context classes.

::: tanjun.context.autocomplete
    options:
        show_root_heading: true

::: tanjun.context.menu
    options:
        show_root_heading: true

::: tanjun.context.message
    options:
        show_root_heading: true

::: tanjun.context.slash
    options:
        show_root_heading: true
